Struct amazon_sp_fulfillment_outbound::models::get_feature_inventory_result::GetFeatureInventoryResult
source · [−]pub struct GetFeatureInventoryResult {
pub marketplace_id: String,
pub feature_name: String,
pub next_token: Option<String>,
pub feature_skus: Option<Vec<FeatureSku>>,
}Expand description
GetFeatureInventoryResult : The payload for the getEligibileInventory operation.
Fields
marketplace_id: StringThe requested marketplace.
feature_name: StringThe name of the feature.
next_token: Option<String>When present and not empty, pass this string token in the next request to return the next response page.
feature_skus: Option<Vec<FeatureSku>>An array of SKUs eligible for this feature and the quantity available.
Implementations
sourceimpl GetFeatureInventoryResult
impl GetFeatureInventoryResult
sourcepub fn new(
marketplace_id: String,
feature_name: String
) -> GetFeatureInventoryResult
pub fn new(
marketplace_id: String,
feature_name: String
) -> GetFeatureInventoryResult
The payload for the getEligibileInventory operation.